#
# spec file for package python-exrex
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-exrex
Version:        0.11.0
Release:        2.0.2.1.sr20250601
Summary:        Irregular methods for regular expressions
License:        AGPL-3.0-or-later
Group:          Development/Languages/Python
URL:            https://github.com/asciimoo/exrex
#Source:         https://files.pythonhosted.org/packages/source/e/exrex/exrex-%%{version}.tar.gz
# pypi has no tests
Source:         https://github.com/asciimoo/exrex/archive/v%{version}.tar.gz#/exrex-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-setuptools
Requires(post): alts
Requires(postun): alts
BuildArch:      noarch
%python_subpackages

%description
A command line tool and python module that generates all or random matching strings to a given regular expression and more.

%prep
%setup -q -n exrex-%{version}
sed -i '1s/^#!.*//' exrex.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/exrex
rm %{buildroot}%{_bindir}/exrex.py
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%{python_expand # comment
LANG=C.UTF-8 PYTHONPATH=%{buildroot}%{$python_sitelib} $python ./tests.py}

%post
%python_install_alternative exrex

%postun
%python_uninstall_alternative exrex

%files %{python_files}
%{python_sitelib}/exrex*
%{python_sitelib}/__pycache__/exrex.*
%{python_sitelib}/exrex-%{version}*-info
%license COPYING
%doc README.md doc/
%python_alternative %{_bindir}/exrex

%changelog
* Tue May 27 2025 Markéta Machová <mmachova@suse.com>
- Convert to pip-based build
* Sun Mar 12 2023 Sebastian Wagner <sebix@sebix.at>
- Update to version 0.11.0:
  - Add support for \w and \W
  - fix utf-8
  - Fix: Import error sre_parse: sre_parse module was moved in py3.11
- remove obsolete fix-setup-encoding.patch
- remove obsolete fix-python-3.11.patch
* Mon Feb 27 2023 Sebastian Wagner <sebix@sebix.at>
- add fix-python-3.11.patch from upstream PR #65 to fix the build on Python 3.11.
* Thu Feb 25 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- add fix-setup-encoding.patch to fix encoding issues in setup.py
- Skip Python 2.
- run the tests.
- remove add-license.patch, included in upstream
- Update to revision 49909345:
  - Fix: added py_modules
  - Fix: Typo in email address
  - Add support for \w and \W
  - Add full license file
  - Add MANIFEST to include metafiles
  - add rstr.xeger
  - README: group related projects and describe them
  - fix: utf-8
  - Add support for min-repeat
  - Escape literal special characters in sre_to_string method.
* Tue May 26 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Mon Jun  3 2019 pgajdos@suse.com
- note there are no upstream tests, run spec-cleaner
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Mar  5 2018 sebix+novell.com@sebix.at
- initial package for version 0.10.5
- add add-license.patch for license
